@@ -12,7 +12,7 @@ init([]) ->
 	% GSUP side
 	HlrIp = application:get_env(osmo_dia2gsup, hlr_ip, "127.0.0.1"),
 	HlrPort = application:get_env(osmo_dia2gsup, hlr_port, 4222),
-	Args = [{local, gsup_client}, gsup_client, [HlrIp, HlrPort, []], [{debug, [trace]}]],
+	Args = [{local, gsup_client}, gsup_client, [HlrIp, HlrPort, "HSS-00-00-00-00-00-00"], []],
 	GsupChild = {gsup_client, {gen_server, start_link, Args}, permanent, 2000, worker, [gsup_client]},
 	% DIAMETER side
         DiaServer = {osmo_dia2gsup,{osmo_dia2gsup,start_link,[]},
